Module sync

Module sync 

Automatic sync/polling for detecting upstream API changes

This module provides functionality to periodically poll upstream APIs, compare responses with recorded fixtures, and detect changes.

Structs

DetectedChange
Detected change in an API response
GitOpsConfig
GitOps configuration for sync
SyncConfig
Sync configuration
SyncService
Sync service for polling upstream APIs and detecting changes
SyncStatus
Sync status
TrafficAwareConfig
Traffic-aware sync configuration